# SPDX-FileCopyrightText: 2025-present s-ball <s-ball@laposte.net>
#
# SPDX-License-Identifier: MIT
"""Main package: declares version, clean and build"""

from .__about__ import __version__
from .build import *
